@@ -1,4 +1,4 @@
-#  Copyright (c) 2020 zfit
+#  Copyright (c) 2021 zfit
 
 import tensorflow as tf
 
@@ -9,7 +9,8 @@ class Adam(WrapOptimizer):
     # todo see why sphinx does not correctly link to WrapOptimizer for api
     _DEFAULT_name = 'Adam'
 
-    def __init__(self, tolerance=None,
+    def __init__(self,
+                 tol=None,
                  learning_rate=0.2,
                  beta1=0.9,
                  beta2=0.999,
@@ -20,4 +21,4 @@ class Adam(WrapOptimizer):
                                              beta_1=beta1, beta_2=beta2,
                                              epsilon=epsilon,
                                              name=name)
-        super().__init__(optimizer=optimizer, tolerance=tolerance, **kwargs)
+        super().__init__(optimizer=optimizer, tol=tol, maxiter=None, **kwargs)
